"use client";

import React, { useEffect, useState } from 'react';
import { Swiper, SwiperSlide } from 'swiper/react';
import 'swiper/css';
import 'swiper/css/pagination';
import 'swiper/css/navigation';
import { Pagination, Autoplay } from 'swiper/modules';
import Link from 'next/link';

const AfricanMovieSlider: React.FC = () => {
  const [africanMovies, setAfricanMovies] = useState<any[]>([]);

  useEffect(() => {
    const fetchAfricanMovies = async () => {
      try {
        const response = await fetch('/data/african.json');
        const data = await response.json();
  
        // Shuffle and slice the array to get 20 random movies
        const shuffledMovies = data.sort(() => 0.5 - Math.random()).slice(0, 20);
  
        setAfricanMovies(shuffledMovies);
      } catch (error) {
        console.error('Failed to fetch African movies:', error);
      }
    };
  
    fetchAfricanMovies();
  }, []);

  return (
    <div className="relative mt-12 animate-fadeInUp">
      <div className="flex justify-between items-center mb-4 mx-4 animate-slideInLeft">
        <h2 className="text-2xl font-bold text-white text-left md:text-2xl sm:text-xl">
          African Movies
        </h2>
        <a href="/africanmovies" className="text-red-500 text-sm md:text-lg hover:underline">
          See All
        </a>
      </div>
      <Swiper
        modules={[Pagination, Autoplay]}
        spaceBetween={5}
        slidesPerView={3} // Default for mobile
        breakpoints={{
          640: {
            slidesPerView: 3, // 3 slides per view on mobile
          },
          768: {
            slidesPerView: 5, // 5 slides per view on tablets
          },
          1024: {
            slidesPerView: 8, // 8 slides per view on PC
          },
        }}
        loop={true}
        autoplay={{ delay: 3000 }}
        pagination={{
          clickable: true,
          bulletClass: 'swiper-pagination-bullet',
          bulletActiveClass: 'swiper-pagination-bullet-active',
        }}
        className="mySwiper"
      >
        {africanMovies.map((movie) => (
          <SwiperSlide key={movie.id}>
            <Link href={`/watch/afriq?videoId=${movie.id}`} passHref>
              <div className="relative p-1 cursor-pointer group">
                {/* Blurred background layer within the thumbnail container */}
                <div className="absolute inset-0 w-full h-full rounded-lg overflow-hidden">
                  <img
                    src={`https://img.youtube.com/vi/${movie.id}/hqdefault.jpg`} // Fetching the thumbnail from YouTube
                    alt={movie.title}
                    className="w-full h-full object-cover filter blur-md transform scale-150" // Scaling the background up
                  />
                </div>

                {/* Foreground image, centered and fitting within the container */}
                <div className="relative z-10 flex justify-center items-center h-[200px] md:h-[300px]">
                  <img
                    src={`https://img.youtube.com/vi/${movie.id}/hqdefault.jpg`} // Fetching the thumbnail from YouTube
                    alt={movie.title}
                    className="max-w-full max-h-full object-contain rounded-lg shadow-lg transition-transform duration-300 ease-in-out transform group-hover:scale-105"
                  />
                </div>

                {/* Country flag */}
                <div className="absolute top-2 right-2 bg-black bg-opacity-70 text-xs px-2 py-1 rounded flex items-center z-20">
                  <img
                    src={`/flags/${movie.country.toLowerCase()}.png`} // Fetching the flag image
                    alt={movie.country}
                    className="w-6 h-4 mr-2"
                  />
                  {movie.country}
                </div>
              </div>
            </Link>
          </SwiperSlide>
        ))}
      </Swiper>
      <div className="mt-4 custom-pagination swiper-pagination"></div>
      <style jsx global>{`
        .swiper-pagination {
          position: relative;
          margin-top: 10px;
        }
        .swiper-pagination-bullet {
          background-color: rgba(255, 255, 255, 0.4);
        }
        .swiper-pagination-bullet-active {
          background-color: red;
        }

        @keyframes fadeInUp {
          from {
            opacity: 0;
            transform: translateY(20px);
          }
          to {
            opacity: 1;
            transform: translateY(0);
          }
        }

        @keyframes slideInLeft {
          from {
            opacity: 0;
            transform: translateX(-20px);
          }
          to {
            opacity: 1);
            transform: translateX(0);
          }
        }

        .animate-fadeInUp {
          animation: fadeInUp 1s ease-in-out;
        }

        .animate-slideInLeft {
          animation: slideInLeft 1s ease-in-out;
        }
      `}</style>
    </div>
  );
};

export default AfricanMovieSlider;
